package implement

import (
	"code.fnuoos.com/EggPlanet/egg_models.git/src/dao"
	"code.fnuoos.com/EggPlanet/egg_models.git/src/model"
	zhios_order_relate_utils "code.fnuoos.com/EggPlanet/egg_models.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/EggPlanet/egg_models.git/utils/logx"
	"xorm.io/xorm"
)

func NewLifeOrderDb(engine *xorm.Engine) dao.LifeOrderDao {
	return &LifeOrderDb{Db: engine}
}

type LifeOrderDb struct {
	Db *xorm.Engine
}

func (j LifeOrderDb) GetLifeOrder(id string) (m *model.LifeOrder, err error) {
	m = new(model.LifeOrder)
	has, err := j.Db.Where("pvd_oid=?", id).Get(m)
	if err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	if has == false {
		return nil, nil
	}
	return m, nil
}
func (j LifeOrderDb) FindLifeOrder(page, limit, title, platform, pvdOid, state, startTime, endTime, settleStartTime, settleEndTime string) (*[]model.LifeOrder, error) {
	var m []model.LifeOrder
	sess := j.Db.Where("1=1")
	start := (zhios_order_relate_utils.StrToInt(page) - 1) * zhios_order_relate_utils.StrToInt(limit)
	if title != "" {
		sess.And("goods_title like ?", "%"+title+"%")
	}
	if platform != "" {
		sess.And("platform = ?", platform)
	}
	if pvdOid != "" {
		sess.And("pvd_oid = ?", pvdOid)
	}
	if state != "" {
		sess.And("state = ?", state)
	}
	if startTime != "" {
		sess.And("create_at >= ?", startTime)
	}
	if endTime != "" {
		sess.And("create_at <= ?", endTime)
	}
	if zhios_order_relate_utils.StrToInt64(settleStartTime) > 0 {
		sess.And("settle_at >= ?", settleStartTime)
	}
	if zhios_order_relate_utils.StrToInt64(settleEndTime) > 0 {
		sess.And("settle_at <= ?", settleEndTime)
	}
	if err := sess.Limit(zhios_order_relate_utils.StrToInt(limit), start).OrderBy("id desc").Find(&m); err != nil {
		return nil, zhios_order_relate_logx.Error(err)
	}
	return &m, nil
}
func (j LifeOrderDb) FindLifeOrderAndTotal(page, limit, title, platform, pvdOid, state, startTime, endTime, settleStartTime, settleEndTime string) (*[]model.LifeOrder, int64, error) {
	var m []model.LifeOrder
	sess := j.Db.Where("1=1")
	start := (zhios_order_relate_utils.StrToInt(page) - 1) * zhios_order_relate_utils.StrToInt(limit)
	if title != "" {
		sess.And("goods_title like ?", "%"+title+"%")
	}
	if platform != "" {
		sess.And("platform = ?", platform)
	}
	if pvdOid != "" {
		sess.And("pvd_oid = ?", pvdOid)
	}
	if state != "" {
		sess.And("state = ?", state)
	}
	if startTime != "" {
		sess.And("create_at >= ?", startTime)
	}
	if endTime != "" {
		sess.And("create_at <= ?", endTime)
	}
	if zhios_order_relate_utils.StrToInt64(settleStartTime) > 0 {
		sess.And("settle_at >= ?", settleStartTime)
	}
	if zhios_order_relate_utils.StrToInt64(settleEndTime) > 0 {
		sess.And("settle_at <= ?", settleEndTime)
	}
	count, err := sess.Limit(zhios_order_relate_utils.StrToInt(limit), start).OrderBy("id desc").FindAndCount(&m)
	if err != nil {
		return nil, count, zhios_order_relate_logx.Error(err)
	}
	return &m, count, nil
}
